@@ -1,5 +1,7 @@
 from .__version__ import __version__
-from .HowFairIsChecker import HowFairIsChecker
+from .Checker import Checker
+from .Config import Config
+from .Repo import Repo
 
 
 __author__ = "https://github.com/jspaaks"
@@ -7,5 +9,7 @@ __email__ = 'j.spaaks@esciencecenter.nl'
 
 __all__ = [
     "__version__",
-    "HowFairIsChecker"
+    "Checker",
+    "Config",
+    "Repo"
 ]
