@@ -1,7 +1,7 @@
 class ChecklistMixin:
 
     def check_checklist(self):
-        force = self.config.get("force", dict())
+        force = self.config.yamldata.get("force", dict())
         if not isinstance(force, dict):
             force = dict()
         force_state = force.get("checklist")
