@@ -5,7 +5,7 @@ from howfairis.Platform import Platform
 class RepositoryMixin:
 
     def check_repository(self):
-        force = self.config.get("force", dict())
+        force = self.config.yamldata.get("force", dict())
         if not isinstance(force, dict):
             force = dict()
         force_state = force.get("repository")
@@ -20,10 +20,10 @@ class RepositoryMixin:
 
     def has_open_repository(self):
 
-        if self.platform == Platform.GITHUB:
-            url = "https://api.github.com/repos/{0}/{1}".format(self.owner, self.repo)
-        elif self.platform == Platform.GITLAB:
-            url = "https://gitlab.com/api/v4/projects/{0}%2F{1}/repository/tree".format(self.owner, self.repo)
+        if self.config.repo.platform == Platform.GITHUB:
+            url = self.config.repo.api
+        elif self.config.repo.platform == Platform.GITLAB:
+            url = self.config.repo.api + "/repository/tree"
 
         try:
             response = requests.get(url)
